@@ -1,7 +1,9 @@
 #!/bin/sh
 
-interface="$(ip tuntap show | cut -d : -f1 | head -n 1)"
-ip="$(ip a s "${interface}" 2>/dev/null \
+interface="$1"
+
+[ -z "$interface" ] && interface="$(ip tuntap show | cut -d : -f1 | head -n 1)"
+ip="$(ip addr show "${interface}" 2>/dev/null \
         | grep -o -P '(?<=inet )[0-9]{1,3}(\.[0-9]{1,3}){3}')"
 
 if [ "${ip}" != "" ]; then
@@ -17,3 +19,4 @@ if [ "${ip}" != "" ]; then
 else
   printf "<txt></txt>"
 fi
+
